@@ -30,15 +30,27 @@
 void show_about_dialog(GtkApplication *app)
 {
   GList * windows = gtk_application_get_windows (app);
+
+  const gchar *authors[] = {
+    "Pierre-Yves Luyten <py@luyten.fr>",
+    NULL
+  };
+
+  const gchar *artists[] = {
+    "William Jon McCann <jmccann@redhat.com>",
+    NULL
+  };
   
   gtk_show_about_dialog( g_list_nth_data (windows, 0),
   "program-name", _("Notes"),
   "comments", _("Simple notebook for GNOME"),
-  "license", "GPLv3",
+  "license-type", GTK_LICENSE_GPL_3_0,
   "version", VERSION,
-  "copyright", "Pierre-Yves Luyten 2013",
+  "copyright", "Copyright © 2013 Pierre-Yves Luyten",
+  "authors", authors,
+  "artists", artists,
   "translator-credits", _("translator-credits"),
-  "website", "https://wiki.gnome.org/Bijiben",
+  "website", "https://wiki.gnome.org/Apps/Bijiben",
   NULL,NULL,NULL);
 
 }
