@@ -25,7 +25,6 @@
 #include "bjb-rename-note.h"
 #include "bjb-share.h"
 #include "bjb-window-base.h"
-#include "utils/bjb-icons-colors.h"
 
 /* All needed toolbars */
 typedef enum
@@ -56,8 +55,6 @@ struct _BjbMainToolbarPrivate
   GtkWidget        *grid;
   GtkWidget        *select;
   GtkWidget        *search;
-  GtkWidget        *separator;
-  GtkWidget        *close;
   gulong            finish_sig;
   gulong            update_selection;
   gulong            search_handler;
@@ -102,8 +99,6 @@ bjb_main_toolbar_clear (BjbMainToolbar *self)
   g_clear_pointer (&self->priv->search   ,gtk_widget_destroy);
   g_clear_pointer (&self->priv->select   ,gtk_widget_destroy);
   g_clear_pointer (&self->priv->share    ,gtk_widget_destroy);
-  g_clear_pointer (&self->priv->separator,gtk_widget_destroy);
-  g_clear_pointer (&self->priv->close    ,gtk_widget_destroy);
 }
 
 /* Callbacks */
@@ -145,8 +140,8 @@ update_selection_label (BjbMainToolbar *self)
     label = g_strdup_printf (g_dngettext (GETTEXT_PACKAGE, "%d selected", "%d selected", length),length);
 
 
-  gtk_header_bar_set_title (GTK_HEADER_BAR (self), NULL);
-  gtk_header_bar_set_subtitle (GTK_HEADER_BAR (self), label);
+  gtk_header_bar_set_title (GTK_HEADER_BAR (self), label);
+  gtk_header_bar_set_subtitle (GTK_HEADER_BAR (self), NULL);
   g_free (label);
 
   return TRUE;
@@ -247,13 +242,6 @@ on_search_button_clicked (BjbMainToolbarPrivate *priv)
   bjb_window_base_set_show_search_bar (BJB_WINDOW_BASE (priv->window), show_bar);
 }
 
-static void
-on_close_clicked (GtkButton *button,
-                  gpointer   user_data)
-{
-  gtk_widget_destroy (GTK_WIDGET (BJB_MAIN_TOOLBAR (user_data)->priv->window));
-}
-
 static void
 add_search_button (BjbMainToolbar *self)
 {
@@ -278,30 +266,6 @@ add_search_button (BjbMainToolbar *self)
                             G_CALLBACK (on_search_button_clicked), priv);
 }
 
-static void
-add_close_button (BjbMainToolbar *self)
-{
-  BjbMainToolbarPrivate *priv = self->priv;
-  GtkWidget *close_image;
-
-  /* Close button */
-  priv->separator = gtk_separator_new (GTK_ORIENTATION_VERTICAL);
-  gtk_widget_set_valign (priv->separator, GTK_ALIGN_FILL);
-  gtk_header_bar_pack_end (GTK_HEADER_BAR (self), priv->separator);
-
-  priv->close = gtk_button_new ();
-  gtk_button_set_relief (GTK_BUTTON (priv->close), GTK_RELIEF_NONE);
-  close_image = gtk_image_new_from_icon_name ("window-close-symbolic", GTK_ICON_SIZE_MENU);
-  gtk_button_set_image (GTK_BUTTON (priv->close), close_image);
-  gtk_widget_set_valign (priv->close, GTK_ALIGN_CENTER);
-  gtk_style_context_add_class (gtk_widget_get_style_context (priv->close),
-                               "image-button");
-  gtk_header_bar_pack_end (GTK_HEADER_BAR (self), priv->close);
-  g_signal_connect (priv->close,"clicked",
-                    G_CALLBACK(on_close_clicked), self);
-}
-
-
 static void
 update_selection_buttons (BjbController *controller,
                           gboolean some_item_is_visible,
@@ -325,6 +289,9 @@ populate_bar_for_selection (BjbMainToolbar *self)
 
   priv = self->priv;
 
+  /* Hide close button */
+  gtk_header_bar_set_show_close_button (GTK_HEADER_BAR (self), FALSE);
+
   /* Search button */
   add_search_button (self);
 
@@ -404,9 +371,7 @@ static void
 populate_bar_for_standard(BjbMainToolbar *self)
 {
   BjbMainToolbarPrivate *priv = self->priv;
-  GtkWidget *bin = NULL;
   BijiCollection *coll;
-  GtkWidget *grid, *notes_icon, *notes_label;
   GtkWidget *select_image;
   gboolean rtl;
 
@@ -420,19 +385,11 @@ populate_bar_for_standard(BjbMainToolbar *self)
   /* Go back to all notes */
   coll = bjb_controller_get_collection (priv->controller);
 
-  if (coll)
+  if (coll != NULL)
   {
-    grid = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
-    notes_icon = get_icon (rtl ? "go-previous-rtl-symbolic" : "go-previous-symbolic");
-    gtk_box_pack_start (GTK_BOX (grid), notes_icon, TRUE, TRUE, TRUE);
-
-    notes_label = gtk_label_new (_("Notes"));
-    gtk_box_pack_start (GTK_BOX (grid), notes_label, TRUE, TRUE, TRUE);
-    priv->back = gtk_button_new ();
+    priv->back = gtk_button_new_from_icon_name (rtl ? "go-previous-rtl-symbolic" : "go-previous-symbolic",
+                                                GTK_ICON_SIZE_MENU);
     gtk_widget_set_valign (priv->back, GTK_ALIGN_CENTER);
-    gtk_style_context_add_class (gtk_widget_get_style_context (priv->back),
-                                 "text-button");
-    gtk_container_add (GTK_CONTAINER (priv->back), grid);
     gtk_header_bar_pack_start (GTK_HEADER_BAR (self), priv->back);
 
     g_signal_connect_swapped (priv->back, "clicked",
@@ -444,18 +401,9 @@ populate_bar_for_standard(BjbMainToolbar *self)
   {
     priv->new = gtk_button_new_with_label (_("New"));
     gtk_widget_set_valign (priv->new, GTK_ALIGN_CENTER);
-    gtk_style_context_add_class (gtk_widget_get_style_context (priv->new),
-                                 "text-button");
+
     gtk_header_bar_pack_start (GTK_HEADER_BAR (self), priv->new);
     gtk_widget_set_size_request (priv->new, 70, -1);
-    bin = gtk_bin_get_child (GTK_BIN (priv->new));
-
-    if (bin)
-    {
-      gint y_padding = 0;
-      gtk_misc_get_padding (GTK_MISC (bin), NULL, &y_padding);
-      gtk_misc_set_padding (GTK_MISC (bin), 12, y_padding);
-    }
 
     g_signal_connect(priv->new,"clicked",
                      G_CALLBACK(on_new_note_clicked),priv->parent);
@@ -474,8 +422,8 @@ populate_bar_for_standard(BjbMainToolbar *self)
   g_signal_connect (priv->select,"clicked",
                     G_CALLBACK(on_selection_mode_clicked),self);
 
-  /* Close button */
-  add_close_button (self);
+  /* Show close button */
+  gtk_header_bar_set_show_close_button (GTK_HEADER_BAR (self), TRUE);
 
   /* Watch for main view changing */
   connect_main_view_handlers (self);
@@ -747,9 +695,7 @@ populate_bar_for_note_view (BjbMainToolbar *self)
 {
   BjbMainToolbarPrivate *priv = self->priv;
   GtkHeaderBar          *bar = GTK_HEADER_BAR (self);
-  BijiCollection        *collection;
   BjbSettings           *settings;
-  GtkWidget             *grid, *notes_icon, *notes_label;
   GdkRGBA                color;
   BijiItem *item;
   GtkWidget *share_image;
@@ -766,20 +712,10 @@ populate_bar_for_note_view (BjbMainToolbar *self)
 
   settings = bjb_app_get_settings (g_application_get_default());
 
-  collection = bjb_controller_get_collection (self->priv->controller);
-
   /* Go to main view basically means closing note */
-  grid = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
-  notes_icon = get_icon (rtl ? "go-previous-rtl-symbolic" : "go-previous-symbolic");
-  gtk_box_pack_start (GTK_BOX (grid), notes_icon, TRUE, TRUE, TRUE);
-
-  notes_label = gtk_label_new (collection ? biji_item_get_title (BIJI_ITEM (collection)) : _("Notes"));
-  gtk_box_pack_start (GTK_BOX (grid), notes_label, TRUE, TRUE, TRUE);
-  priv->back = gtk_button_new ();
+  priv->back = gtk_button_new_from_icon_name (rtl ? "go-previous-rtl-symbolic" : "go-previous-symbolic",
+                                              GTK_ICON_SIZE_MENU);
   gtk_widget_set_valign (priv->back, GTK_ALIGN_CENTER);
-  gtk_style_context_add_class (gtk_widget_get_style_context (priv->back),
-                               "text-button");
-  gtk_container_add (GTK_CONTAINER (priv->back), grid);
   gtk_header_bar_pack_start (bar, priv->back);
  
   g_signal_connect_swapped (priv->back, "clicked",
@@ -859,8 +795,8 @@ populate_bar_for_note_view (BjbMainToolbar *self)
   gtk_header_bar_pack_end (bar, priv->menu);
   gtk_widget_set_tooltip_text (priv->menu, _("More options…"));
 
-  /* Close button */
-  add_close_button (self);
+  /* Show close button */
+  gtk_header_bar_set_show_close_button (GTK_HEADER_BAR (self), TRUE);
 
   gtk_menu_button_set_popup (GTK_MENU_BUTTON (priv->menu),
                              bjb_note_menu_new (self));
@@ -903,7 +839,7 @@ populate_bar_switch (BjbMainToolbar *self)
 
     /* Spinner, Empty Results */
     default:
-      add_close_button (self);
+      gtk_header_bar_set_show_close_button (GTK_HEADER_BAR (self), TRUE);
       break;
   }
 
